<template>
  <a-modal
    :title="title"
    :width="1050"
    :visible="visible"
    :maskClosable="false"
    :confirmLoading="confirmLoading"
    :okButtonProps="{ props: {disabled: disableSubmit} }"
    @ok="handleOk"
    @cancel="handleCancel"
    cancelText="关闭"
  >
    <a-spin :spinning="confirmLoading">
      <a-form :form="form">

      </a-form>
    </a-spin>

    <a-button
      type="primary"
      :style="{ marginRight: '8px',marginBottom:'8px' }"
      :loading="confirmLoading"
      @click="selectSafetyRequirement()"
    >危险防控</a-button>
    <a-table
      ref="table"
      bordered
      size="middle"
      rowKey='id'
      :columns="columns"
      :dataSource="dataSource"
    >

      <span
        slot="action"
        slot-scope="text, record, index"
      >
        <a-popconfirm
          title="确定删除吗?"
          @confirm="() => handleDelete(text,record, index)"
        >
          <a>删除</a>
        </a-popconfirm>
      </span>
    </a-table>

    <template slot="footer">
      <a-button
        :style="{marginRight: '8px'}"
        @click="handleCancel"
      >
        关闭
      </a-button>
      <a-button
        :disabled="disableSubmit || confirmLoading"
        :loading="confirmLoading"
        @click="handleOk"
        type="primary"
      >确定</a-button>
    </template>
    <j-select-maintenance-standard-safety-requirement-modal ref="maintenanceStandardSafetyRequirementModalForm"></j-select-maintenance-standard-safety-requirement-modal>
  </a-modal>
</template>

<script>
import pick from 'lodash.pick'
import { postAction, requestPut } from '@/api/manage'
import { duplicateCheck } from '@/api/api'
import JSelectMaintenanceStandardSafetyRequirementModal from './JSelectMaintenanceStandardSafetyRequirementModal'

export default {
  name: 'MaintenanceStandardSafetyRequirementModal',
  components: {
    JSelectMaintenanceStandardSafetyRequirementModal
  },
  data() {
    return {
      title: "操作",
      visible: false,
      codeDisable: true,
      disableSubmit: false,
      maintenanceStandardId: '',
      dataSource: [],
      model: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 6 },
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 18 },
      },
      confirmLoading: false,
      form: this.$form.createForm(this),
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          align: 'center',
          customRender: function (t, r, index) {
            return parseInt(index) + 1
          },
          width: 50,
        },
        {
          title: '危险源编码',
          align: 'center',
          dataIndex: 'num'
        },

        {
          title: '危险源',
          align: 'center',
          dataIndex: 'name'
        },
        {
          title: '危险描述',
          align: 'center',
          dataIndex: 'description'
        },
        {
          title: '防控措施',
          align: 'center',
          dataIndex: 'measure'
        },
        {
          title: '操作',
          align: 'center',
          dataIndex: 'action',
          scopedSlots: {
            customRender: 'action'
          },
        }
      ],
      url: {
        add: "/eam/maintenanceStandardSafetyRequirement/add",
        edit: "/eam/maintenanceStandardSafetyRequirement/edit"
      },
      //新增、编辑、删除、批量删除操作改变数据后刷新关联的组件的监听属性
      alterFlag: "",
    }
  },
  created() {
  },

  mounted() {
    this.$bus.$on('selection2Rows', (data) => {
      for (let i = 0; i < data.length; i++) {
        this.dataSource.push({
          id: data[i].id,
          num: data[i].num,
          name: data[i].name,
          description: data[i].description,
          measure: data[i].measure,
        })
      }
    })
  },
  methods: {

    add() {
      this.dataSource = [];
      this.edit({});
    },

    edit(record) {
      this.form.resetFields();
      this.model = Object.assign({}, record);
      this.visible = true;
      this.disableSubmit = false;
      if (record.id) {
        this.codeDisable = true;
      } else {
        this.codeDisable = false;
      }
    },

    close() {
      this.$emit('close');
      this.visible = false;
    },

    //保存并新增按钮触发


    handleOk() {
      const that = this;
      // 触发表单验证
      this.form.validateFields((err, values) => {
        if (!err) {
          that.confirmLoading = true;
          let formData = Object.assign(this.model, values);
          formData.maintenanceStandardId = this.maintenanceStandardId;
          formData.riskPreventionList = this.dataSource;
          let obj;
          if (!this.model.id) {
            obj = postAction(this.url.add, formData);
          } else {
            obj = requestPut(this.url.edit, formData, { id: this.model.id });
          }
          obj.then((res) => {
            if (res.success) {
              that.$message.success(res.message);
              that.$emit('ok');
              that.alterFlag = new Date();
            } else {
              that.$message.warning(res.message);
            }
          }).finally(() => {
            that.confirmLoading = false;
            that.close();
          })
        }
      })
    },

    handleCancel() {
      this.close()
    },

    handleDelete(text, record, index) {
      this.dataSource.splice(index, 1);
    },

    selectSafetyRequirement: function () {
      let ids = [];
      for (let i = 0; i < this.dataSource.length; i++) {
        ids.push(this.dataSource[i].id);
      }
      this.$refs.maintenanceStandardSafetyRequirementModalForm.showModals(ids);
      this.$refs.maintenanceStandardSafetyRequirementModalForm.title = '选择危险防控';
      this.$refs.maintenanceStandardSafetyRequirementModalForm.disableSubmit = false;
    },

  },
}
</script>

<style scoped>
.ant-btn {
  padding: 0 10px;
  margin-left: 3px;
}

.ant-form-item-control {
  line-height: 0px;
}

/** 主表单行间距 */
.ant-form .ant-form-item {
  margin-bottom: 10px;
}

/** Tab页面行间距 */
.ant-tabs-content .ant-form-item {
  margin-bottom: 0px;
}
</style>